@@ -40,8 +40,8 @@ class GitRssPlugin(BasePlugin):
     config_scheme = (
         ("abstract_chars_count", config_options.Type(int, default=150)),
         ("category", config_options.Type(str, default=None)),
-        ("exclude_files", config_options.Type(list, default=[])),
         ("feed_ttl", config_options.Type(int, default=1440)),
+        ("image", config_options.Type(str, default=None)),
         ("length", config_options.Type(int, default=20)),
     )
 
@@ -90,6 +90,10 @@ class GitRssPlugin(BasePlugin):
             "ttl": self.config.get("feed_ttl", None),
         }
 
+        # feed image
+        if self.config.get("image"):
+            base_feed["logo_url"] = self.config.get("image")
+
         # create 2 final dicts
         self.feed_created = deepcopy(base_feed)
         self.feed_updated = deepcopy(base_feed)
@@ -112,6 +116,8 @@ class GitRssPlugin(BasePlugin):
                 "See: https://validator.w3.org/feed/docs/rss2.html#requiredChannelElements"
             )
 
+        
+
         # ending event
         return config
 
@@ -147,6 +153,7 @@ class GitRssPlugin(BasePlugin):
                 description=self.util.get_description_or_abstract(
                     in_page=page, chars_count=self.config.get("abstract_chars_count")
                 ),
+                image=self.util.get_image(in_page=page, base_url=config.get("site_url", __uri__)),
                 url_full=page.canonical_url,
             )
         )
@@ -167,31 +174,18 @@ class GitRssPlugin(BasePlugin):
         out_feed_updated = Path(config.get("site_dir")) / OUTPUT_FEED_UPDATED
 
         # created items
-        for page in sorted(
-            self.pages_to_filter, key=lambda page: page.created, reverse=True
-        )[: self.config.get("length", 20)]:
-            self.feed_created.get("entries").append(
-                {
-                    "description": page.description,
-                    "link": page.url_full,
-                    "pubDate": formatdate(page.created),
-                    "title": page.title,
-                }
-            )
+        self.feed_created.get("entries").extend(self.util.filter_pages(
+            pages=self.pages_to_filter,
+            attribute="created",
+            length=self.config.get('length', 20)
+        ))
 
         # updated items
-        for page in sorted(
-            self.pages_to_filter, key=lambda page: page.updated, reverse=True
-        )[: self.config.get("length", 20)]:
-            self.feed_updated["entries"].append(
-                {
-                    "description": page.description,
-                    "link": page.url_full,
-                    "pubDate": formatdate(page.updated),
-                    "title": page.title,
-                }
-            )
-
+        self.feed_created.get("entries").extend(self.util.filter_pages(
+            pages=self.pages_to_filter,
+            attribute="updated",
+            length=self.config.get('length', 20)
+        ))
         # load Jinja environment
         env = Environment(
             loader=FileSystemLoader(self.tpl_folder),
